/**
 * MySQL-Fill
 *
 * @author Henrique Salvadori Coelho
 *         henriquesc@gmail.com
 *         http://hcoelho.com
 *         https://github.com/hscasn
 *
 *
 ***************************************************
 *
 * @typedef {{
 *   name: string,
 *   type: string,
 *   isNull?: boolean,
 *   disabled?: boolean,
 *   size?: number,
 *   autoIncrement?: boolean,
 *   primaryKey?: boolean,
 *   defaultValue?: string|undefined,
 *   options?: string|undefined
 * }} Column
 *
 * @typedef {{
 *   name: string,
 *   description?: string,
 *   disabled?: boolean,
 *   columns: [Column],
 *   foreignKeys?: [ForeignKey],
 *   unique?: [string],
 *   index?: [string],
 * }} Table
 *
 * @typedef {{
 * }} Settings
 *
 * @typedef {{
 *  column: string,
 *  referenceTable: string,
 *  referenceColumn: string,
 *  onDelete?: string,
 *  onUpdate?: string
 * }} ForeignKey
 */

const database = require('./lib/database');

module.exports = async function (log, connectionOptions, structure, verbose = false) {

  const settings = {
    connectionOptions,
    structure,
  };

  try {
    log('Checking database structure');
    await database.expand(settings, log, verbose);
    log('Done checking database structure');
  }
  catch(e) {
    log(e);
  }
};